@@ -1,12 +1,25 @@
 use std::sync::mpsc::channel;
 
 use crate::checkers::CheckerTypes;
+use crate::decoders::atbash_decoder::AtbashDecoder;
+use crate::decoders::base32_decoder::Base32Decoder;
+use crate::decoders::base58_bitcoin_decoder::Base58BitcoinDecoder;
+use crate::decoders::base58_monero_decoder::Base58MoneroDecoder;
+
+use crate::decoders::base58_flickr_decoder::Base58FlickrDecoder;
+use crate::decoders::base58_ripple_decoder::Base58RippleDecoder;
+
 ///! Proposal: https://broadleaf-angora-7db.notion.site/Filtration-System-7143b36a42f1466faea3077bfc7e859e
 ///! Given a filter object, return an array of decoders/crackers which have been filtered
 ///
 use crate::decoders::base64_decoder::Base64Decoder;
+use crate::decoders::base64_url_decoder::Base64URLDecoder;
+use crate::decoders::base65536_decoder::Base65536Decoder;
+use crate::decoders::caesar_decoder::CaesarDecoder;
+use crate::decoders::citrix_ctx1_decoder::CitrixCTX1Decoder;
 use crate::decoders::crack_results::CrackResult;
 use crate::decoders::interface::{Crack, Decoder};
+use crate::decoders::morse_code::MorseCodeDecoder;
 use crate::decoders::reverse_decoder::ReverseDecoder;
 
 use log::trace;
@@ -87,10 +100,35 @@ impl MyResults {
 /// Currently takes no args as this is just a spike to get all the basic functionality working
 pub fn filter_and_get_decoders() -> Decoders {
     trace!("Filtering and getting all decoders");
+    let base58_bitcoin = Decoder::<Base58BitcoinDecoder>::new();
+    let base58_monero = Decoder::<Base58MoneroDecoder>::new();
+    let base58_ripple = Decoder::<Base58RippleDecoder>::new();
+    let base58_flickr = Decoder::<Base58FlickrDecoder>::new();
     let base64 = Decoder::<Base64Decoder>::new();
+    let base64_url = Decoder::<Base64URLDecoder>::new();
+    let base65536 = Decoder::<Base65536Decoder>::new();
+    let citrix_ctx1 = Decoder::<CitrixCTX1Decoder>::new();
+    let base32 = Decoder::<Base32Decoder>::new();
     let reversedecoder = Decoder::<ReverseDecoder>::new();
+    let morsecodedecoder = Decoder::<MorseCodeDecoder>::new();
+    let atbashdecoder = Decoder::<AtbashDecoder>::new();
+    let caesardecoder = Decoder::<CaesarDecoder>::new();
     Decoders {
-        components: vec![Box::new(base64), Box::new(reversedecoder)],
+        components: vec![
+            Box::new(base58_bitcoin),
+            Box::new(base58_monero),
+            Box::new(base58_ripple),
+            Box::new(base58_flickr),
+            Box::new(base64),
+            Box::new(base64_url),
+            Box::new(base65536),
+            Box::new(citrix_ctx1),
+            Box::new(base32),
+            Box::new(reversedecoder),
+            Box::new(morsecodedecoder),
+            Box::new(atbashdecoder),
+            Box::new(caesardecoder),
+        ],
     }
 }
 
