@@ -13,10 +13,12 @@ pub static DICTIONARIES: Lazy<HashMap<&str, HashSet<&str>>> = Lazy::new(|| {
     let mut entries = HashMap::new();
 
     for entry in DICTIONARIES_DIR.files() {
-        let content = entry.contents_utf8().unwrap();
+        let content = entry.contents_utf8().expect("The file you moved into the dictionaries folder is not UTF-8. The storage module only works on UTF-8 files.");
         let hash_set: HashSet<&str> = content.split_ascii_whitespace().collect();
 
-        let filename = entry.path().to_str().unwrap();
+        let filename = entry.path().to_str().expect(
+            "Cannot turn filename of the file you moved into the Dictionaries folder into a string",
+        );
 
         entries.insert(filename, hash_set);
     }
